PyXMake Developer Guide: PyXMake.Plugin.__poetry.ApplicationPlugin Class Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Classes | Public Member Functions | Public Attributes | List of all members
PyXMake.Plugin.__poetry.ApplicationPlugin Class Reference
Inheritance diagram for PyXMake.Plugin.__poetry.ApplicationPlugin:

## Classes
class | Command

## Public Member Functions
| run (self, application)
| activate (self, application)

## Public Attributes
| Command

## Detailed Description

    Poetry application plugin interface

Definition at line 137 of file __poetry.py.

## Member Function Documentation

## ◆ activate()

PyXMake.Plugin.__poetry.ApplicationPlugin.activate | ( |  | self,
|  |  | application )

    Poetry application registration interface

Definition at line 190 of file __poetry.py.

## ◆ run()

PyXMake.Plugin.__poetry.ApplicationPlugin.run | ( |  | self,
|  |  | application )

    Poetry application command line interface

Definition at line 153 of file __poetry.py.

## Member Data Documentation

## ◆ Command

PyXMake.Plugin.__poetry.ApplicationPlugin.Command

Definition at line 202 of file __poetry.py.

The documentation for this class was generated from the following file:

- src/PyXMake/Plugin/__poetry.py